OC.L10N.register(
    "dav",
    {
    "Calendar" : "日曆",
    "Todos" : "待辦事項",
    "Personal" : "個人",
    "{actor} created calendar {calendar}" : "{actor} 建立了日曆 {calendar}",
    "You created calendar {calendar}" : "您建立了日曆 {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} 刪除了日曆 {calendar}",
    "You deleted calendar {calendar}" : "您刪除了日曆 {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} 更新了日曆 {calendar}",
    "You updated calendar {calendar}" : "你更新了日曆 {calendar}",
    "You shared calendar {calendar} as public link" : "你將 {calendar} 日曆以公開連結分享",
    "You removed public link for calendar {calendar}" : "您刪除了 {calendar} 的公開分享連結",
    "{actor} shared calendar {calendar} with you" : "{actor} 與你分享了{calendar} ",
    "You shared calendar {calendar} with {user}" : "你與 {user} 分享了 {calendar} ",
    "{actor} shared calendar {calendar} with {user}" : "{actor} 與 {user} 分享了日曆 {calendar} ",
    "{actor} unshared calendar {calendar} from you" : "{actor} 停止與您分享日曆 {calendar}",
    "You unshared calendar {calendar} from {user}" : "您停止與 {user} 分享日曆 {calendar}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} 停止與 {user} 分享日曆 {calendar}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} 停止與他們自己分享日曆 {calendar}",
    "You shared calendar {calendar} with group {group}" : "您與群組 {group} 分享了日曆 {calendar}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} 與群組 {group} 分享了日曆 {calendar}",
    "You unshared calendar {calendar} from group {group}" : "您已停止與群組 {group} 分享日曆 {calendar}",
    "You updated event {event} in calendar {calendar}" : "您更新了日曆 {calendar}中的事件{event}",
    "Busy" : "忙碌中",
    "You reopened todo {todo} in list {calendar}" : "你重新開啟了 {calendar} 清單中的代辦事項 {todo}",
    "A <strong>calendar</strong> was modified" : "一個<strong>日曆</strong>被更動",
    "A calendar <strong>event</strong> was modified" : "一個日曆<strong>活動</strong>被更動",
    "A calendar <strong>todo</strong> was modified" : "一個日曆<strong>代辦事項</strong>被更動",
    "Contact birthdays" : "聯絡人生日",
    "Where:" : "地點",
    "Description:" : "描述",
    "%1$s via %2$s" : "%1$s 由 %2$s",
    "Invitation canceled" : "邀請被取消了",
    "Invitation updated" : "邀請更新",
    "Location:" : "地點：",
    "Link:" : "連結",
    "Accept" : "接受",
    "Decline" : "拒絕",
    "More options …" : "更多選項 ...",
    "More options at %s" : "%s有更多選項",
    "Contacts" : "聯絡人",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "您的 %s 必須要設定 HTTPS ，才能在 iOS/macOS 上使用 CalDAV 和 CardDAV",
    "Configures a CalDAV account" : "設定一個 CalDAV 帳號",
    "Configures a CardDAV account" : "設定一個 CardDAV 帳號",
    "Tasks" : "工作項目",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "WebDAV 端點",
    "There was an error updating your attendance status." : "更新您的參與狀況時發生錯誤",
    "Please contact the organizer directly." : "請直接聯繫主辦人",
    "Are you accepting the invitation?" : "接受邀請嗎？",
    "Tentative" : "測試的",
    "Save" : "儲存",
    "Your attendance was updated successfully." : "您的參與狀況成功更新",
    "Calendar server" : "日曆伺服器",
    "Send invitations to attendees" : "發送邀請函給參加者",
    "Automatically generate a birthday calendar" : "自動建立 生日 日曆",
    "Birthday calendars will be generated by a background job." : "生日日曆 將會在 後台 建立",
    "Hello %s," : "%s您好，",
    "The meeting »%1$s« with %2$s was canceled." : "與 %2$s 的會議 %1$s 取消了",
    "The meeting »%1$s« with %2$s was updated." : "與 %2$s 的會議 %1$s 有變動",
    "%1$s invited you to »%2$s«" : "%1$s邀請您到%2$s",
    "When:" : "時間"
},
"nplurals=1; plural=0;");
